@@ -1749,7 +1749,7 @@ class DcdbClient(AbstractClient):
 
 
     def TerminateDedicatedDBInstance(self, request):
-        """本接口（IsolateDedicatedDBInstance）用于销毁已隔离的独享分布式数据库实例。
+        """本接口（TerminateDedicatedDBInstance）用于销毁已隔离的独享分布式数据库实例。
 
         :param request: Request instance for TerminateDedicatedDBInstance.
         :type request: :class:`tencentcloud.dcdb.v20180411.models.TerminateDedicatedDBInstanceRequest`
